close all; clear all; clc;
% spracovanie a jednoduche modelovanie profilovych mikrogravimetrickych dat

% niektore dolezite premenne, najma s poctami bodov:
% n - pocet vsetkych udajov v subore z gravimetra
% n_zb - pocet citani na zakladnom bode
% n_mb - pocet meracich gravimetrickych bodov (okrem zakladnych bodov)

% nacitanie suboru s meranymi udajmi do matice grav_data
grav_data = load('Gagar_raw.dat');
% vyseparovanie jednotlivych stlpcov: bod, cas, grav
bod = grav_data(:,1); cas = grav_data(:,2); grav = grav_data(:,3);
% zistenie poctu nacitanych dat (pocet riadkov) a ulozenie do jednoprvkovej matice n
n = numel(bod);

% vyseparovanie merani na zakladnom bode (s cislom 1) a beznych meracich bodov
n_zb = 0; n_mb = 0;%n_zb - pocet ZB, n_mb - pocet meracich bodov
for i = 1:n
    if bod(i) == 1 %ked sa cislo bodu rovna 1
    n_zb = n_zb + 1; zb_cas(n_zb) = cas(i); zb_grav(n_zb) = grav(i); %zvysi sa zistene poradove cislo zb a ulozia sa cas a grav
    else n_mb = n_mb + 1; mb_bod(n_mb) = bod(i); mb_cas(n_mb) = cas(i); mb_grav(n_mb) = grav(i); %obdobne pre profilove body
    end;%koniec podmienky if bod(i) = 1
end;%koniec cyklu for i=1:n
% graf meraneho tiazoveho zrychlenia
figure, plot(mb_bod,mb_grav,'--o','LineWidth',2,'MarkerEdgeColor','b','MarkerFaceColor','b','MarkerSize',4);
xlabel('x [m]','FontSize',10); ylabel('g mer [mGal]','FontSize',10);title('namerane tiazove zrychlenie');

% nacitanie suboru s informaciou o hodnote zrychlenia na ZB
ZB = load('Gagar_base_station.dat');

% vyseparovanie hodnoty zrychlenia na ZB
ZB_hodnota = ZB(:,2);

% stupen polynomu pri oprave o chod
n_polynom = 3;
%LSQ-method - nafitovanie polynomu na seriu dvojic [zb_cas,zb_grav]
koef_polynom = polyfit(zb_cas,zb_grav,n_polynom);

%vypocet krivky chodu pre dany stupen polynomu
for j = 1:n_mb
    switch n_polynom
    case 1 
    chod(j) = koef_polynom(1)*mb_cas(j) + koef_polynom(2); %pre n_polynom=1; 
    ZB_chod_prvy = koef_polynom(1)*cas(1) + koef_polynom(2); %pomocna hodnota - chod pre prve meranie na ZB
    case 2
    chod(j) = koef_polynom(1)*mb_cas(j)^2 + koef_polynom(2)*mb_cas(j) + koef_polynom(3); %pre n_polynom=2;
    ZB_chod_prvy = koef_polynom(1)*cas(1)^2 + koef_polynom(2)*cas(1) + koef_polynom(3); %pomocna hodnota - chod pre prve meranie na ZB
    case 3
    chod(j) = koef_polynom(1)*mb_cas(j)^3 + koef_polynom(2)*mb_cas(j)^2 + koef_polynom(3)*mb_cas(j) + koef_polynom(4); %pre n_polynom=3; 
    ZB_chod_prvy = koef_polynom(1)*cas(1)^3 + koef_polynom(2)*cas(1)^2 + koef_polynom(3)*cas(1) + koef_polynom(4); %pomocna hodnota - chod pre prve meranie na ZB
    end;%koniec prikazu switch
end;%koniec cyklu for j=1:n_mb

% vykreslenie chodu
figure, plot(zb_cas,zb_grav,'--rs','LineWidth',2,'MarkerEdgeColor','k','MarkerFaceColor','g','MarkerSize',10);
hold on;
plot(mb_cas,chod); xlabel('cas [hod.]','FontSize',10); ylabel('grav [mGal]','FontSize',10); legend('ZB'); title('chod');

% oprava o chod
for j = 1:n_mb
    mb_oprav_grav(j) = mb_grav(j) - chod(j); 
end;%koniec cyklu for j=1:n_mb
ZB_oprav_chod_prvy = grav(1) - ZB_chod_prvy; %oprava (o chod) hodnoty pre prve meranie na ZB (mala by vyjst hodnota blizka nule)

% prepocet na hodnotu ZB (na absolutne hodnoty)
for j = 1:n_mb
    mb_abs_grav(j) = (mb_oprav_grav(j) - ZB_oprav_chod_prvy) + ZB_hodnota;
end;%koniec cyklu for j=1:n_mb
% graf tiazoveho zrychlenia opraveneho o chod a prepocitaneho na absolutne hodnoty
figure, plot(mb_bod,mb_abs_grav,'--o','LineWidth',2,'MarkerEdgeColor','b','MarkerFaceColor','b','MarkerSize',4);
xlabel('x [m]','FontSize',10); ylabel('g abs [mGal]','FontSize',10);title('opravene a prepocitane tiazove zrychlenie');

%nacitanie suboru s vyskami
elev_data = load('Gagar_elev.dat');
%vyseparovanie stlpca s vyskami
vyska = elev_data(:,2);
% graf vysok
figure, plot(mb_bod, vyska,'--go','LineWidth',2,'MarkerEdgeColor','g','MarkerFaceColor','g','MarkerSize',4);
xlabel('x [m]','FontSize',10); ylabel('relat. nadm. vysky [m]','FontSize',10);title('vysky');

% vypocet NBA
for j = 1:n_mb
    NBA(j) = mb_abs_grav(j) + 0.3086*vyska(j)-0.0419*2*vyska(j);
end;% koniec cyklu for j = 1:n_mb

% modelovanie pola Vz (2D horizontalny valec)
% uzivatel meni hustotu ro, hlbku h, polomer R, posuny pozdlz x-ovej a hodnotovej osi 
kappa = 6.67e-11; ro = -1800; R = 2.3;  h = 4;
    for j = 1:n_mb
        Vz(j) = 2*1E5*kappa*pi*R*R*ro*h/((mb_bod(j)-13)^2+h*h) + 144.88; %posuny anomalie zistene experimentalne
    end;

% graf NBA + modelovane pole Vz
%figure, plotyy(mb_bod, NBA, mb_bod,Vz); xlabel('x [m]','FontSize',10); ylabel('[mGal]','FontSize',10);title('vysledna a modelovana krivka');
figure, plot(mb_bod,NBA,'--o','LineWidth',2,'MarkerEdgeColor','b','MarkerFaceColor','b','MarkerSize',4);
hold on;
plot(mb_bod,Vz);xlabel('x [m]','FontSize',10); ylabel('[mGal]','FontSize',10);title('vysledna a modelovana krivka');

% KONIEC SKRiPTU

